Context
=======

.. py:module:: moderngl
.. py:currentmodule:: moderngl

Let's create a Standalone Context for now.
It will help us write less code.
Later you can reuse this code to render directly to a window.

.. literalinclude:: first.1.py
    :linenos:

Proceed to the :doc:`next step <program>`.
